==> dda-user-crate-0.4.0-20170602.104842-8.jar: dda/pallet/domain/dda_user_crate.clj <==
; Licensed to the Apache Software Foundation (ASF) under one
; or more contributor license agreements. See the NOTICE file
; distributed with this work for additional information
; regarding copyright ownership. The ASF licenses this file
; to you under the Apache License, Version 2.0 (the
; "License"); you may not use this file except in compliance
; with the License. You may obtain a copy of the License at
;
; http://www.apache.org/licenses/LICENSE-2.0
;
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
(ns dda.pallet.domain.dda-user-crate
  (:require
   [schema.core :as s]
   [pallet.api :as api]
   [dda.pallet.crate.config :as config-crate]
   [dda.pallet.crate.dda-user-crate :as user-crate]))

(def UserDomainConfig
  user-crate/UserCrateConfig)

(def UserCrateStackConfig
  {:group-specific-config
   {s/Keyword {:dda-user user-crate/UserCrateConfig}}})

(s/defn ^:always-validate crate-stack-configuration :- UserCrateStackConfig
  ([domain-config :- UserDomainConfig]
   {:group-specific-config
    {:dda-user-group {:dda-user domain-config}}})
  ([group-key :- s/Keyword
    domain-config :- UserDomainConfig]
   {:group-specific-config
    {group-key {:dda-user domain-config}}}))

(s/defn ^:always-validate dda-user-group
  [config :- UserCrateStackConfig]
  (api/group-spec
    "dda-user-group"
    :extends [(config-crate/with-config config)
              user-crate/with-user]))

==> dda-user-crate-0.4.0-20170602.112159-9.jar: dda/pallet/domain/dda_user_crate.clj <==
; Licensed to the Apache Software Foundation (ASF) under one
; or more contributor license agreements. See the NOTICE file
; distributed with this work for additional information
; regarding copyright ownership. The ASF licenses this file
; to you under the Apache License, Version 2.0 (the
; "License"); you may not use this file except in compliance
; with the License. You may obtain a copy of the License at
;
; http://www.apache.org/licenses/LICENSE-2.0
;
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
(ns dda.pallet.domain.dda-user-crate
  (:require
   [schema.core :as s]
   [pallet.api :as api]
   [dda.pallet.crate.config :as config-crate]
   [dda.pallet.crate.dda-user-crate :as user-crate]))

(def UserDomainConfig
  user-crate/UserCrateConfig)

(def UserCrateStackConfig
  {:group-specific-config
   {s/Keyword {:dda-user user-crate/UserCrateConfig}}})

(defn crate-stack-configuration [domain-config
                                 & {:keys [group-key] :or {group-key :dda-user-group}}]
   (s/validate s/Keyword group-key)
   (s/validate UserDomainConfig domain-config)
   (s/validate
    UserCrateStackConfig
    {:group-specific-config
      {group-key {:dda-user domain-config}}}))

(s/defn ^:always-validate dda-user-group
  [config :- UserCrateStackConfig]
  (let
    [group-name (name (key (:group-specific-config config)))]
    (api/group-spec
      group-name
      :extends [(config-crate/with-config config)
                user-crate/with-user])))
